export declare type IPath = string | string[];
export interface IDBOperations {
    collection(path: IPath): Collection;
    keys(path: IPath): Promise<string[]>;
    get<T>(path: IPath): Promise<T>;
    set(path: IPath, value: any): Promise<void>;
    push(path: IPath, value: any): Promise<string>;
    subscribe<T>(path: IPath, type: "push" | "set", ondata: (data: T) => void): Promise<{
        unsubscribe: () => void;
    }>;
}
export declare class Collection implements IDBOperations {
    private db;
    private prefix;
    constructor(db: Database, prefix: string[]);
    collection(path: string | string[]): Collection;
    keys(path: string | string[]): Promise<any>;
    get<T = any>(path: string | string[]): Promise<T>;
    set(path: string | string[], data: any): Promise<any>;
    push(path: string | string[], data: any): Promise<string>;
    subscribe<T>(path: string | string[], type: "push" | "set", ondata: (data: T) => void): Promise<{
        unsubscribe: () => void;
    }>;
}
export default class Database implements IDBOperations {
    static WebSocket: typeof WebSocket;
    private initLock;
    private socket;
    private requests;
    private eventhandler;
    constructor(url: string, database: string, accesskey?: string, authkey?: string, rootkey?: string);
    private handleResponse;
    private handleEvent;
    private queryRequest;
    collection(path: IPath): Collection;
    keys(path: IPath): Promise<any>;
    get<T = any>(path: IPath): Promise<T>;
    set(path: IPath, data: any): Promise<any>;
    push(path: IPath, data: any): Promise<string>;
    subscribe(path: IPath, type: "push" | "set", ondata: (data: any) => void): Promise<{
        unsubscribe: () => void;
    }>;
}
